# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import cacheclient_pb2 as cacheclient__pb2


class ScsStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/cache_client.Scs/Get',
                request_serializer=cacheclient__pb2._GetRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._GetResponse.FromString,
                )
        self.GetBatch = channel.unary_stream(
                '/cache_client.Scs/GetBatch',
                request_serializer=cacheclient__pb2._GetBatchRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._GetResponse.FromString,
                )
        self.Set = channel.unary_unary(
                '/cache_client.Scs/Set',
                request_serializer=cacheclient__pb2._SetRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._SetResponse.FromString,
                )
        self.SetBatch = channel.unary_stream(
                '/cache_client.Scs/SetBatch',
                request_serializer=cacheclient__pb2._SetBatchRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._SetResponse.FromString,
                )
        self.SetIf = channel.unary_unary(
                '/cache_client.Scs/SetIf',
                request_serializer=cacheclient__pb2._SetIfRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._SetIfResponse.FromString,
                )
        self.SetIfNotExists = channel.unary_unary(
                '/cache_client.Scs/SetIfNotExists',
                request_serializer=cacheclient__pb2._SetIfNotExistsRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._SetIfNotExistsResponse.FromString,
                )
        self.Delete = channel.unary_unary(
                '/cache_client.Scs/Delete',
                request_serializer=cacheclient__pb2._DeleteRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._DeleteResponse.FromString,
                )
        self.KeysExist = channel.unary_unary(
                '/cache_client.Scs/KeysExist',
                request_serializer=cacheclient__pb2._KeysExistRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._KeysExistResponse.FromString,
                )
        self.Increment = channel.unary_unary(
                '/cache_client.Scs/Increment',
                request_serializer=cacheclient__pb2._IncrementRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._IncrementResponse.FromString,
                )
        self.UpdateTtl = channel.unary_unary(
                '/cache_client.Scs/UpdateTtl',
                request_serializer=cacheclient__pb2._UpdateTtlRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._UpdateTtlResponse.FromString,
                )
        self.ItemGetTtl = channel.unary_unary(
                '/cache_client.Scs/ItemGetTtl',
                request_serializer=cacheclient__pb2._ItemGetTtlRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._ItemGetTtlResponse.FromString,
                )
        self.ItemGetType = channel.unary_unary(
                '/cache_client.Scs/ItemGetType',
                request_serializer=cacheclient__pb2._ItemGetTypeRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._ItemGetTypeResponse.FromString,
                )
        self.DictionaryGet = channel.unary_unary(
                '/cache_client.Scs/DictionaryGet',
                request_serializer=cacheclient__pb2._DictionaryGetRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._DictionaryGetResponse.FromString,
                )
        self.DictionaryFetch = channel.unary_unary(
                '/cache_client.Scs/DictionaryFetch',
                request_serializer=cacheclient__pb2._DictionaryFetchRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._DictionaryFetchResponse.FromString,
                )
        self.DictionarySet = channel.unary_unary(
                '/cache_client.Scs/DictionarySet',
                request_serializer=cacheclient__pb2._DictionarySetRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._DictionarySetResponse.FromString,
                )
        self.DictionaryIncrement = channel.unary_unary(
                '/cache_client.Scs/DictionaryIncrement',
                request_serializer=cacheclient__pb2._DictionaryIncrementRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._DictionaryIncrementResponse.FromString,
                )
        self.DictionaryDelete = channel.unary_unary(
                '/cache_client.Scs/DictionaryDelete',
                request_serializer=cacheclient__pb2._DictionaryDeleteRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._DictionaryDeleteResponse.FromString,
                )
        self.DictionaryLength = channel.unary_unary(
                '/cache_client.Scs/DictionaryLength',
                request_serializer=cacheclient__pb2._DictionaryLengthRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._DictionaryLengthResponse.FromString,
                )
        self.SetFetch = channel.unary_unary(
                '/cache_client.Scs/SetFetch',
                request_serializer=cacheclient__pb2._SetFetchRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._SetFetchResponse.FromString,
                )
        self.SetSample = channel.unary_unary(
                '/cache_client.Scs/SetSample',
                request_serializer=cacheclient__pb2._SetSampleRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._SetSampleResponse.FromString,
                )
        self.SetUnion = channel.unary_unary(
                '/cache_client.Scs/SetUnion',
                request_serializer=cacheclient__pb2._SetUnionRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._SetUnionResponse.FromString,
                )
        self.SetDifference = channel.unary_unary(
                '/cache_client.Scs/SetDifference',
                request_serializer=cacheclient__pb2._SetDifferenceRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._SetDifferenceResponse.FromString,
                )
        self.SetContains = channel.unary_unary(
                '/cache_client.Scs/SetContains',
                request_serializer=cacheclient__pb2._SetContainsRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._SetContainsResponse.FromString,
                )
        self.SetLength = channel.unary_unary(
                '/cache_client.Scs/SetLength',
                request_serializer=cacheclient__pb2._SetLengthRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._SetLengthResponse.FromString,
                )
        self.SetPop = channel.unary_unary(
                '/cache_client.Scs/SetPop',
                request_serializer=cacheclient__pb2._SetPopRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._SetPopResponse.FromString,
                )
        self.ListPushFront = channel.unary_unary(
                '/cache_client.Scs/ListPushFront',
                request_serializer=cacheclient__pb2._ListPushFrontRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._ListPushFrontResponse.FromString,
                )
        self.ListPushBack = channel.unary_unary(
                '/cache_client.Scs/ListPushBack',
                request_serializer=cacheclient__pb2._ListPushBackRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._ListPushBackResponse.FromString,
                )
        self.ListPopFront = channel.unary_unary(
                '/cache_client.Scs/ListPopFront',
                request_serializer=cacheclient__pb2._ListPopFrontRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._ListPopFrontResponse.FromString,
                )
        self.ListPopBack = channel.unary_unary(
                '/cache_client.Scs/ListPopBack',
                request_serializer=cacheclient__pb2._ListPopBackRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._ListPopBackResponse.FromString,
                )
        self.ListErase = channel.unary_unary(
                '/cache_client.Scs/ListErase',
                request_serializer=cacheclient__pb2._ListEraseRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._ListEraseResponse.FromString,
                )
        self.ListRemove = channel.unary_unary(
                '/cache_client.Scs/ListRemove',
                request_serializer=cacheclient__pb2._ListRemoveRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._ListRemoveResponse.FromString,
                )
        self.ListFetch = channel.unary_unary(
                '/cache_client.Scs/ListFetch',
                request_serializer=cacheclient__pb2._ListFetchRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._ListFetchResponse.FromString,
                )
        self.ListLength = channel.unary_unary(
                '/cache_client.Scs/ListLength',
                request_serializer=cacheclient__pb2._ListLengthRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._ListLengthResponse.FromString,
                )
        self.ListConcatenateFront = channel.unary_unary(
                '/cache_client.Scs/ListConcatenateFront',
                request_serializer=cacheclient__pb2._ListConcatenateFrontRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._ListConcatenateFrontResponse.FromString,
                )
        self.ListConcatenateBack = channel.unary_unary(
                '/cache_client.Scs/ListConcatenateBack',
                request_serializer=cacheclient__pb2._ListConcatenateBackRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._ListConcatenateBackResponse.FromString,
                )
        self.ListRetain = channel.unary_unary(
                '/cache_client.Scs/ListRetain',
                request_serializer=cacheclient__pb2._ListRetainRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._ListRetainResponse.FromString,
                )
        self.SortedSetPut = channel.unary_unary(
                '/cache_client.Scs/SortedSetPut',
                request_serializer=cacheclient__pb2._SortedSetPutRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._SortedSetPutResponse.FromString,
                )
        self.SortedSetFetch = channel.unary_unary(
                '/cache_client.Scs/SortedSetFetch',
                request_serializer=cacheclient__pb2._SortedSetFetchRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._SortedSetFetchResponse.FromString,
                )
        self.SortedSetGetScore = channel.unary_unary(
                '/cache_client.Scs/SortedSetGetScore',
                request_serializer=cacheclient__pb2._SortedSetGetScoreRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._SortedSetGetScoreResponse.FromString,
                )
        self.SortedSetRemove = channel.unary_unary(
                '/cache_client.Scs/SortedSetRemove',
                request_serializer=cacheclient__pb2._SortedSetRemoveRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._SortedSetRemoveResponse.FromString,
                )
        self.SortedSetIncrement = channel.unary_unary(
                '/cache_client.Scs/SortedSetIncrement',
                request_serializer=cacheclient__pb2._SortedSetIncrementRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._SortedSetIncrementResponse.FromString,
                )
        self.SortedSetGetRank = channel.unary_unary(
                '/cache_client.Scs/SortedSetGetRank',
                request_serializer=cacheclient__pb2._SortedSetGetRankRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._SortedSetGetRankResponse.FromString,
                )
        self.SortedSetLength = channel.unary_unary(
                '/cache_client.Scs/SortedSetLength',
                request_serializer=cacheclient__pb2._SortedSetLengthRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._SortedSetLengthResponse.FromString,
                )
        self.SortedSetLengthByScore = channel.unary_unary(
                '/cache_client.Scs/SortedSetLengthByScore',
                request_serializer=cacheclient__pb2._SortedSetLengthByScoreRequest.SerializeToString,
                response_deserializer=cacheclient__pb2._SortedSetLengthByScoreResponse.FromString,
                )


class ScsServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Get(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBatch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Set(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetBatch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetIf(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetIfNotExists(self, request, context):
        """Deprecated because we have SetIf - Absent to cover this case.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def KeysExist(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Increment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateTtl(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ItemGetTtl(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ItemGetType(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DictionaryGet(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DictionaryFetch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DictionarySet(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DictionaryIncrement(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DictionaryDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DictionaryLength(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetFetch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetSample(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetUnion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDifference(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetContains(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetLength(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetPop(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPushFront(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPushBack(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPopFront(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPopBack(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListErase(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListRemove(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListFetch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListLength(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListConcatenateFront(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListConcatenateBack(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListRetain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SortedSetPut(self, request, context):
        """Sorted Set Operations
        A sorted set is a collection of elements ordered by their score.
        The elements with same score are ordered lexicographically.

        Add or Updates new element with its score to the Sorted Set.
        If sorted set doesn't exist, a new one is created with the specified
        element and its associated score.
        If an element exists, then its associate score gets overridden with the one
        provided in this operation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SortedSetFetch(self, request, context):
        """Fetches a subset of elements in the sorted set.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SortedSetGetScore(self, request, context):
        """Gets the specified element and its associated score if it exists in the
        sorted set.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SortedSetRemove(self, request, context):
        """Removes specified elements and their associated scores
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SortedSetIncrement(self, request, context):
        """Changes the score associated with the element by specified amount.
        If the provided amount is negative, then the score associated with the
        element is decremented.
        If the element that needs to be incremented isn't present in the sorted
        set, it is added with specified number as the score.
        If the set itself doesn't exist then a new one with specified element and
        score is created.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SortedSetGetRank(self, request, context):
        """Gives the rank of an element.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SortedSetLength(self, request, context):
        """Returns length of the sorted set
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SortedSetLengthByScore(self, request, context):
        """Returns number of elements in the sorted set between a given min and max score
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ScsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=cacheclient__pb2._GetRequest.FromString,
                    response_serializer=cacheclient__pb2._GetResponse.SerializeToString,
            ),
            'GetBatch': grpc.unary_stream_rpc_method_handler(
                    servicer.GetBatch,
                    request_deserializer=cacheclient__pb2._GetBatchRequest.FromString,
                    response_serializer=cacheclient__pb2._GetResponse.SerializeToString,
            ),
            'Set': grpc.unary_unary_rpc_method_handler(
                    servicer.Set,
                    request_deserializer=cacheclient__pb2._SetRequest.FromString,
                    response_serializer=cacheclient__pb2._SetResponse.SerializeToString,
            ),
            'SetBatch': grpc.unary_stream_rpc_method_handler(
                    servicer.SetBatch,
                    request_deserializer=cacheclient__pb2._SetBatchRequest.FromString,
                    response_serializer=cacheclient__pb2._SetResponse.SerializeToString,
            ),
            'SetIf': grpc.unary_unary_rpc_method_handler(
                    servicer.SetIf,
                    request_deserializer=cacheclient__pb2._SetIfRequest.FromString,
                    response_serializer=cacheclient__pb2._SetIfResponse.SerializeToString,
            ),
            'SetIfNotExists': grpc.unary_unary_rpc_method_handler(
                    servicer.SetIfNotExists,
                    request_deserializer=cacheclient__pb2._SetIfNotExistsRequest.FromString,
                    response_serializer=cacheclient__pb2._SetIfNotExistsResponse.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=cacheclient__pb2._DeleteRequest.FromString,
                    response_serializer=cacheclient__pb2._DeleteResponse.SerializeToString,
            ),
            'KeysExist': grpc.unary_unary_rpc_method_handler(
                    servicer.KeysExist,
                    request_deserializer=cacheclient__pb2._KeysExistRequest.FromString,
                    response_serializer=cacheclient__pb2._KeysExistResponse.SerializeToString,
            ),
            'Increment': grpc.unary_unary_rpc_method_handler(
                    servicer.Increment,
                    request_deserializer=cacheclient__pb2._IncrementRequest.FromString,
                    response_serializer=cacheclient__pb2._IncrementResponse.SerializeToString,
            ),
            'UpdateTtl': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateTtl,
                    request_deserializer=cacheclient__pb2._UpdateTtlRequest.FromString,
                    response_serializer=cacheclient__pb2._UpdateTtlResponse.SerializeToString,
            ),
            'ItemGetTtl': grpc.unary_unary_rpc_method_handler(
                    servicer.ItemGetTtl,
                    request_deserializer=cacheclient__pb2._ItemGetTtlRequest.FromString,
                    response_serializer=cacheclient__pb2._ItemGetTtlResponse.SerializeToString,
            ),
            'ItemGetType': grpc.unary_unary_rpc_method_handler(
                    servicer.ItemGetType,
                    request_deserializer=cacheclient__pb2._ItemGetTypeRequest.FromString,
                    response_serializer=cacheclient__pb2._ItemGetTypeResponse.SerializeToString,
            ),
            'DictionaryGet': grpc.unary_unary_rpc_method_handler(
                    servicer.DictionaryGet,
                    request_deserializer=cacheclient__pb2._DictionaryGetRequest.FromString,
                    response_serializer=cacheclient__pb2._DictionaryGetResponse.SerializeToString,
            ),
            'DictionaryFetch': grpc.unary_unary_rpc_method_handler(
                    servicer.DictionaryFetch,
                    request_deserializer=cacheclient__pb2._DictionaryFetchRequest.FromString,
                    response_serializer=cacheclient__pb2._DictionaryFetchResponse.SerializeToString,
            ),
            'DictionarySet': grpc.unary_unary_rpc_method_handler(
                    servicer.DictionarySet,
                    request_deserializer=cacheclient__pb2._DictionarySetRequest.FromString,
                    response_serializer=cacheclient__pb2._DictionarySetResponse.SerializeToString,
            ),
            'DictionaryIncrement': grpc.unary_unary_rpc_method_handler(
                    servicer.DictionaryIncrement,
                    request_deserializer=cacheclient__pb2._DictionaryIncrementRequest.FromString,
                    response_serializer=cacheclient__pb2._DictionaryIncrementResponse.SerializeToString,
            ),
            'DictionaryDelete': grpc.unary_unary_rpc_method_handler(
                    servicer.DictionaryDelete,
                    request_deserializer=cacheclient__pb2._DictionaryDeleteRequest.FromString,
                    response_serializer=cacheclient__pb2._DictionaryDeleteResponse.SerializeToString,
            ),
            'DictionaryLength': grpc.unary_unary_rpc_method_handler(
                    servicer.DictionaryLength,
                    request_deserializer=cacheclient__pb2._DictionaryLengthRequest.FromString,
                    response_serializer=cacheclient__pb2._DictionaryLengthResponse.SerializeToString,
            ),
            'SetFetch': grpc.unary_unary_rpc_method_handler(
                    servicer.SetFetch,
                    request_deserializer=cacheclient__pb2._SetFetchRequest.FromString,
                    response_serializer=cacheclient__pb2._SetFetchResponse.SerializeToString,
            ),
            'SetSample': grpc.unary_unary_rpc_method_handler(
                    servicer.SetSample,
                    request_deserializer=cacheclient__pb2._SetSampleRequest.FromString,
                    response_serializer=cacheclient__pb2._SetSampleResponse.SerializeToString,
            ),
            'SetUnion': grpc.unary_unary_rpc_method_handler(
                    servicer.SetUnion,
                    request_deserializer=cacheclient__pb2._SetUnionRequest.FromString,
                    response_serializer=cacheclient__pb2._SetUnionResponse.SerializeToString,
            ),
            'SetDifference': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDifference,
                    request_deserializer=cacheclient__pb2._SetDifferenceRequest.FromString,
                    response_serializer=cacheclient__pb2._SetDifferenceResponse.SerializeToString,
            ),
            'SetContains': grpc.unary_unary_rpc_method_handler(
                    servicer.SetContains,
                    request_deserializer=cacheclient__pb2._SetContainsRequest.FromString,
                    response_serializer=cacheclient__pb2._SetContainsResponse.SerializeToString,
            ),
            'SetLength': grpc.unary_unary_rpc_method_handler(
                    servicer.SetLength,
                    request_deserializer=cacheclient__pb2._SetLengthRequest.FromString,
                    response_serializer=cacheclient__pb2._SetLengthResponse.SerializeToString,
            ),
            'SetPop': grpc.unary_unary_rpc_method_handler(
                    servicer.SetPop,
                    request_deserializer=cacheclient__pb2._SetPopRequest.FromString,
                    response_serializer=cacheclient__pb2._SetPopResponse.SerializeToString,
            ),
            'ListPushFront': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPushFront,
                    request_deserializer=cacheclient__pb2._ListPushFrontRequest.FromString,
                    response_serializer=cacheclient__pb2._ListPushFrontResponse.SerializeToString,
            ),
            'ListPushBack': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPushBack,
                    request_deserializer=cacheclient__pb2._ListPushBackRequest.FromString,
                    response_serializer=cacheclient__pb2._ListPushBackResponse.SerializeToString,
            ),
            'ListPopFront': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPopFront,
                    request_deserializer=cacheclient__pb2._ListPopFrontRequest.FromString,
                    response_serializer=cacheclient__pb2._ListPopFrontResponse.SerializeToString,
            ),
            'ListPopBack': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPopBack,
                    request_deserializer=cacheclient__pb2._ListPopBackRequest.FromString,
                    response_serializer=cacheclient__pb2._ListPopBackResponse.SerializeToString,
            ),
            'ListErase': grpc.unary_unary_rpc_method_handler(
                    servicer.ListErase,
                    request_deserializer=cacheclient__pb2._ListEraseRequest.FromString,
                    response_serializer=cacheclient__pb2._ListEraseResponse.SerializeToString,
            ),
            'ListRemove': grpc.unary_unary_rpc_method_handler(
                    servicer.ListRemove,
                    request_deserializer=cacheclient__pb2._ListRemoveRequest.FromString,
                    response_serializer=cacheclient__pb2._ListRemoveResponse.SerializeToString,
            ),
            'ListFetch': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFetch,
                    request_deserializer=cacheclient__pb2._ListFetchRequest.FromString,
                    response_serializer=cacheclient__pb2._ListFetchResponse.SerializeToString,
            ),
            'ListLength': grpc.unary_unary_rpc_method_handler(
                    servicer.ListLength,
                    request_deserializer=cacheclient__pb2._ListLengthRequest.FromString,
                    response_serializer=cacheclient__pb2._ListLengthResponse.SerializeToString,
            ),
            'ListConcatenateFront': grpc.unary_unary_rpc_method_handler(
                    servicer.ListConcatenateFront,
                    request_deserializer=cacheclient__pb2._ListConcatenateFrontRequest.FromString,
                    response_serializer=cacheclient__pb2._ListConcatenateFrontResponse.SerializeToString,
            ),
            'ListConcatenateBack': grpc.unary_unary_rpc_method_handler(
                    servicer.ListConcatenateBack,
                    request_deserializer=cacheclient__pb2._ListConcatenateBackRequest.FromString,
                    response_serializer=cacheclient__pb2._ListConcatenateBackResponse.SerializeToString,
            ),
            'ListRetain': grpc.unary_unary_rpc_method_handler(
                    servicer.ListRetain,
                    request_deserializer=cacheclient__pb2._ListRetainRequest.FromString,
                    response_serializer=cacheclient__pb2._ListRetainResponse.SerializeToString,
            ),
            'SortedSetPut': grpc.unary_unary_rpc_method_handler(
                    servicer.SortedSetPut,
                    request_deserializer=cacheclient__pb2._SortedSetPutRequest.FromString,
                    response_serializer=cacheclient__pb2._SortedSetPutResponse.SerializeToString,
            ),
            'SortedSetFetch': grpc.unary_unary_rpc_method_handler(
                    servicer.SortedSetFetch,
                    request_deserializer=cacheclient__pb2._SortedSetFetchRequest.FromString,
                    response_serializer=cacheclient__pb2._SortedSetFetchResponse.SerializeToString,
            ),
            'SortedSetGetScore': grpc.unary_unary_rpc_method_handler(
                    servicer.SortedSetGetScore,
                    request_deserializer=cacheclient__pb2._SortedSetGetScoreRequest.FromString,
                    response_serializer=cacheclient__pb2._SortedSetGetScoreResponse.SerializeToString,
            ),
            'SortedSetRemove': grpc.unary_unary_rpc_method_handler(
                    servicer.SortedSetRemove,
                    request_deserializer=cacheclient__pb2._SortedSetRemoveRequest.FromString,
                    response_serializer=cacheclient__pb2._SortedSetRemoveResponse.SerializeToString,
            ),
            'SortedSetIncrement': grpc.unary_unary_rpc_method_handler(
                    servicer.SortedSetIncrement,
                    request_deserializer=cacheclient__pb2._SortedSetIncrementRequest.FromString,
                    response_serializer=cacheclient__pb2._SortedSetIncrementResponse.SerializeToString,
            ),
            'SortedSetGetRank': grpc.unary_unary_rpc_method_handler(
                    servicer.SortedSetGetRank,
                    request_deserializer=cacheclient__pb2._SortedSetGetRankRequest.FromString,
                    response_serializer=cacheclient__pb2._SortedSetGetRankResponse.SerializeToString,
            ),
            'SortedSetLength': grpc.unary_unary_rpc_method_handler(
                    servicer.SortedSetLength,
                    request_deserializer=cacheclient__pb2._SortedSetLengthRequest.FromString,
                    response_serializer=cacheclient__pb2._SortedSetLengthResponse.SerializeToString,
            ),
            'SortedSetLengthByScore': grpc.unary_unary_rpc_method_handler(
                    servicer.SortedSetLengthByScore,
                    request_deserializer=cacheclient__pb2._SortedSetLengthByScoreRequest.FromString,
                    response_serializer=cacheclient__pb2._SortedSetLengthByScoreResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cache_client.Scs', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Scs(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/Get',
            cacheclient__pb2._GetRequest.SerializeToString,
            cacheclient__pb2._GetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/cache_client.Scs/GetBatch',
            cacheclient__pb2._GetBatchRequest.SerializeToString,
            cacheclient__pb2._GetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Set(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/Set',
            cacheclient__pb2._SetRequest.SerializeToString,
            cacheclient__pb2._SetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetBatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/cache_client.Scs/SetBatch',
            cacheclient__pb2._SetBatchRequest.SerializeToString,
            cacheclient__pb2._SetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetIf(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/SetIf',
            cacheclient__pb2._SetIfRequest.SerializeToString,
            cacheclient__pb2._SetIfResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetIfNotExists(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/SetIfNotExists',
            cacheclient__pb2._SetIfNotExistsRequest.SerializeToString,
            cacheclient__pb2._SetIfNotExistsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/Delete',
            cacheclient__pb2._DeleteRequest.SerializeToString,
            cacheclient__pb2._DeleteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def KeysExist(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/KeysExist',
            cacheclient__pb2._KeysExistRequest.SerializeToString,
            cacheclient__pb2._KeysExistResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Increment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/Increment',
            cacheclient__pb2._IncrementRequest.SerializeToString,
            cacheclient__pb2._IncrementResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateTtl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/UpdateTtl',
            cacheclient__pb2._UpdateTtlRequest.SerializeToString,
            cacheclient__pb2._UpdateTtlResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ItemGetTtl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/ItemGetTtl',
            cacheclient__pb2._ItemGetTtlRequest.SerializeToString,
            cacheclient__pb2._ItemGetTtlResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ItemGetType(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/ItemGetType',
            cacheclient__pb2._ItemGetTypeRequest.SerializeToString,
            cacheclient__pb2._ItemGetTypeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DictionaryGet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/DictionaryGet',
            cacheclient__pb2._DictionaryGetRequest.SerializeToString,
            cacheclient__pb2._DictionaryGetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DictionaryFetch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/DictionaryFetch',
            cacheclient__pb2._DictionaryFetchRequest.SerializeToString,
            cacheclient__pb2._DictionaryFetchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DictionarySet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/DictionarySet',
            cacheclient__pb2._DictionarySetRequest.SerializeToString,
            cacheclient__pb2._DictionarySetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DictionaryIncrement(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/DictionaryIncrement',
            cacheclient__pb2._DictionaryIncrementRequest.SerializeToString,
            cacheclient__pb2._DictionaryIncrementResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DictionaryDelete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/DictionaryDelete',
            cacheclient__pb2._DictionaryDeleteRequest.SerializeToString,
            cacheclient__pb2._DictionaryDeleteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DictionaryLength(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/DictionaryLength',
            cacheclient__pb2._DictionaryLengthRequest.SerializeToString,
            cacheclient__pb2._DictionaryLengthResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetFetch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/SetFetch',
            cacheclient__pb2._SetFetchRequest.SerializeToString,
            cacheclient__pb2._SetFetchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetSample(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/SetSample',
            cacheclient__pb2._SetSampleRequest.SerializeToString,
            cacheclient__pb2._SetSampleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetUnion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/SetUnion',
            cacheclient__pb2._SetUnionRequest.SerializeToString,
            cacheclient__pb2._SetUnionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDifference(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/SetDifference',
            cacheclient__pb2._SetDifferenceRequest.SerializeToString,
            cacheclient__pb2._SetDifferenceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetContains(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/SetContains',
            cacheclient__pb2._SetContainsRequest.SerializeToString,
            cacheclient__pb2._SetContainsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetLength(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/SetLength',
            cacheclient__pb2._SetLengthRequest.SerializeToString,
            cacheclient__pb2._SetLengthResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetPop(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/SetPop',
            cacheclient__pb2._SetPopRequest.SerializeToString,
            cacheclient__pb2._SetPopResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPushFront(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/ListPushFront',
            cacheclient__pb2._ListPushFrontRequest.SerializeToString,
            cacheclient__pb2._ListPushFrontResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPushBack(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/ListPushBack',
            cacheclient__pb2._ListPushBackRequest.SerializeToString,
            cacheclient__pb2._ListPushBackResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPopFront(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/ListPopFront',
            cacheclient__pb2._ListPopFrontRequest.SerializeToString,
            cacheclient__pb2._ListPopFrontResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPopBack(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/ListPopBack',
            cacheclient__pb2._ListPopBackRequest.SerializeToString,
            cacheclient__pb2._ListPopBackResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListErase(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/ListErase',
            cacheclient__pb2._ListEraseRequest.SerializeToString,
            cacheclient__pb2._ListEraseResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListRemove(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/ListRemove',
            cacheclient__pb2._ListRemoveRequest.SerializeToString,
            cacheclient__pb2._ListRemoveResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListFetch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/ListFetch',
            cacheclient__pb2._ListFetchRequest.SerializeToString,
            cacheclient__pb2._ListFetchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListLength(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/ListLength',
            cacheclient__pb2._ListLengthRequest.SerializeToString,
            cacheclient__pb2._ListLengthResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListConcatenateFront(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/ListConcatenateFront',
            cacheclient__pb2._ListConcatenateFrontRequest.SerializeToString,
            cacheclient__pb2._ListConcatenateFrontResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListConcatenateBack(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/ListConcatenateBack',
            cacheclient__pb2._ListConcatenateBackRequest.SerializeToString,
            cacheclient__pb2._ListConcatenateBackResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListRetain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/ListRetain',
            cacheclient__pb2._ListRetainRequest.SerializeToString,
            cacheclient__pb2._ListRetainResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SortedSetPut(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/SortedSetPut',
            cacheclient__pb2._SortedSetPutRequest.SerializeToString,
            cacheclient__pb2._SortedSetPutResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SortedSetFetch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/SortedSetFetch',
            cacheclient__pb2._SortedSetFetchRequest.SerializeToString,
            cacheclient__pb2._SortedSetFetchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SortedSetGetScore(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/SortedSetGetScore',
            cacheclient__pb2._SortedSetGetScoreRequest.SerializeToString,
            cacheclient__pb2._SortedSetGetScoreResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SortedSetRemove(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/SortedSetRemove',
            cacheclient__pb2._SortedSetRemoveRequest.SerializeToString,
            cacheclient__pb2._SortedSetRemoveResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SortedSetIncrement(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/SortedSetIncrement',
            cacheclient__pb2._SortedSetIncrementRequest.SerializeToString,
            cacheclient__pb2._SortedSetIncrementResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SortedSetGetRank(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/SortedSetGetRank',
            cacheclient__pb2._SortedSetGetRankRequest.SerializeToString,
            cacheclient__pb2._SortedSetGetRankResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SortedSetLength(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/SortedSetLength',
            cacheclient__pb2._SortedSetLengthRequest.SerializeToString,
            cacheclient__pb2._SortedSetLengthResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SortedSetLengthByScore(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.Scs/SortedSetLengthByScore',
            cacheclient__pb2._SortedSetLengthByScoreRequest.SerializeToString,
            cacheclient__pb2._SortedSetLengthByScoreResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: permissionmessages.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18permissionmessages.proto\x12\x13permission_messages\"\x94\x01\n\x0bPermissions\x12?\n\nsuper_user\x18\x01 \x01(\x0e\x32).permission_messages.SuperUserPermissionsH\x00\x12<\n\x08\x65xplicit\x18\x02 \x01(\x0b\x32(.permission_messages.ExplicitPermissionsH\x00\x42\x06\n\x04kind\"P\n\x13\x45xplicitPermissions\x12\x39\n\x0bpermissions\x18\x01 \x03(\x0b\x32$.permission_messages.PermissionsType\"\xee\x08\n\x0fPermissionsType\x12R\n\x11\x63\x61\x63he_permissions\x18\x01 \x01(\x0b\x32\x35.permission_messages.PermissionsType.CachePermissionsH\x00\x12R\n\x11topic_permissions\x18\x02 \x01(\x0b\x32\x35.permission_messages.PermissionsType.TopicPermissionsH\x00\x1a\x05\n\x03\x41ll\x1a-\n\rCacheSelector\x12\x14\n\ncache_name\x18\x01 \x01(\tH\x00\x42\x06\n\x04kind\x1a@\n\x11\x43\x61\x63heItemSelector\x12\r\n\x03key\x18\x01 \x01(\x0cH\x00\x12\x14\n\nkey_prefix\x18\x02 \x01(\x0cH\x00\x42\x06\n\x04kind\x1a\xf5\x02\n\x10\x43\x61\x63hePermissions\x12,\n\x04role\x18\x01 \x01(\x0e\x32\x1e.permission_messages.CacheRole\x12>\n\nall_caches\x18\x02 \x01(\x0b\x32(.permission_messages.PermissionsType.AllH\x00\x12L\n\x0e\x63\x61\x63he_selector\x18\x03 \x01(\x0b\x32\x32.permission_messages.PermissionsType.CacheSelectorH\x00\x12=\n\tall_items\x18\x04 \x01(\x0b\x32(.permission_messages.PermissionsType.AllH\x01\x12O\n\ritem_selector\x18\x05 \x01(\x0b\x32\x36.permission_messages.PermissionsType.CacheItemSelectorH\x01\x42\x07\n\x05\x63\x61\x63heB\x0c\n\ncache_item\x1aJ\n\rTopicSelector\x12\x14\n\ntopic_name\x18\x01 \x01(\tH\x00\x12\x1b\n\x11topic_name_prefix\x18\x02 \x01(\tH\x00\x42\x06\n\x04kind\x1a\xee\x02\n\x10TopicPermissions\x12,\n\x04role\x18\x01 \x01(\x0e\x32\x1e.permission_messages.TopicRole\x12>\n\nall_caches\x18\x02 \x01(\x0b\x32(.permission_messages.PermissionsType.AllH\x00\x12L\n\x0e\x63\x61\x63he_selector\x18\x03 \x01(\x0b\x32\x32.permission_messages.PermissionsType.CacheSelectorH\x00\x12>\n\nall_topics\x18\x04 \x01(\x0b\x32(.permission_messages.PermissionsType.AllH\x01\x12L\n\x0etopic_selector\x18\x05 \x01(\x0b\x32\x32.permission_messages.PermissionsType.TopicSelectorH\x01\x42\x07\n\x05\x63\x61\x63heB\x07\n\x05topicB\x06\n\x04kind*[\n\tCacheRole\x12\x13\n\x0f\x43\x61\x63hePermitNone\x10\x00\x12\x12\n\x0e\x43\x61\x63heReadWrite\x10\x01\x12\x11\n\rCacheReadOnly\x10\x02\x12\x12\n\x0e\x43\x61\x63heWriteOnly\x10\x03*[\n\tTopicRole\x12\x13\n\x0fTopicPermitNone\x10\x00\x12\x12\n\x0eTopicReadWrite\x10\x01\x12\x11\n\rTopicReadOnly\x10\x02\x12\x12\n\x0eTopicWriteOnly\x10\x03*%\n\x14SuperUserPermissions\x12\r\n\tSuperUser\x10\x00\x42r\n\x18grpc.permission_messagesP\x01Z0github.com/momentohq/client-sdk-go;client_sdk_go\xaa\x02!Momento.Protos.PermissionMessagesb\x06proto3')

_CACHEROLE = DESCRIPTOR.enum_types_by_name['CacheRole']
CacheRole = enum_type_wrapper.EnumTypeWrapper(_CACHEROLE)
_TOPICROLE = DESCRIPTOR.enum_types_by_name['TopicRole']
TopicRole = enum_type_wrapper.EnumTypeWrapper(_TOPICROLE)
_SUPERUSERPERMISSIONS = DESCRIPTOR.enum_types_by_name['SuperUserPermissions']
SuperUserPermissions = enum_type_wrapper.EnumTypeWrapper(_SUPERUSERPERMISSIONS)
CachePermitNone = 0
CacheReadWrite = 1
CacheReadOnly = 2
CacheWriteOnly = 3
TopicPermitNone = 0
TopicReadWrite = 1
TopicReadOnly = 2
TopicWriteOnly = 3
SuperUser = 0


_PERMISSIONS = DESCRIPTOR.message_types_by_name['Permissions']
_EXPLICITPERMISSIONS = DESCRIPTOR.message_types_by_name['ExplicitPermissions']
_PERMISSIONSTYPE = DESCRIPTOR.message_types_by_name['PermissionsType']
_PERMISSIONSTYPE_ALL = _PERMISSIONSTYPE.nested_types_by_name['All']
_PERMISSIONSTYPE_CACHESELECTOR = _PERMISSIONSTYPE.nested_types_by_name['CacheSelector']
_PERMISSIONSTYPE_CACHEITEMSELECTOR = _PERMISSIONSTYPE.nested_types_by_name['CacheItemSelector']
_PERMISSIONSTYPE_CACHEPERMISSIONS = _PERMISSIONSTYPE.nested_types_by_name['CachePermissions']
_PERMISSIONSTYPE_TOPICSELECTOR = _PERMISSIONSTYPE.nested_types_by_name['TopicSelector']
_PERMISSIONSTYPE_TOPICPERMISSIONS = _PERMISSIONSTYPE.nested_types_by_name['TopicPermissions']
Permissions = _reflection.GeneratedProtocolMessageType('Permissions', (_message.Message,), {
  'DESCRIPTOR' : _PERMISSIONS,
  '__module__' : 'permissionmessages_pb2'
  # @@protoc_insertion_point(class_scope:permission_messages.Permissions)
  })
_sym_db.RegisterMessage(Permissions)

ExplicitPermissions = _reflection.GeneratedProtocolMessageType('ExplicitPermissions', (_message.Message,), {
  'DESCRIPTOR' : _EXPLICITPERMISSIONS,
  '__module__' : 'permissionmessages_pb2'
  # @@protoc_insertion_point(class_scope:permission_messages.ExplicitPermissions)
  })
_sym_db.RegisterMessage(ExplicitPermissions)

PermissionsType = _reflection.GeneratedProtocolMessageType('PermissionsType', (_message.Message,), {

  'All' : _reflection.GeneratedProtocolMessageType('All', (_message.Message,), {
    'DESCRIPTOR' : _PERMISSIONSTYPE_ALL,
    '__module__' : 'permissionmessages_pb2'
    # @@protoc_insertion_point(class_scope:permission_messages.PermissionsType.All)
    })
  ,

  'CacheSelector' : _reflection.GeneratedProtocolMessageType('CacheSelector', (_message.Message,), {
    'DESCRIPTOR' : _PERMISSIONSTYPE_CACHESELECTOR,
    '__module__' : 'permissionmessages_pb2'
    # @@protoc_insertion_point(class_scope:permission_messages.PermissionsType.CacheSelector)
    })
  ,

  'CacheItemSelector' : _reflection.GeneratedProtocolMessageType('CacheItemSelector', (_message.Message,), {
    'DESCRIPTOR' : _PERMISSIONSTYPE_CACHEITEMSELECTOR,
    '__module__' : 'permissionmessages_pb2'
    # @@protoc_insertion_point(class_scope:permission_messages.PermissionsType.CacheItemSelector)
    })
  ,

  'CachePermissions' : _reflection.GeneratedProtocolMessageType('CachePermissions', (_message.Message,), {
    'DESCRIPTOR' : _PERMISSIONSTYPE_CACHEPERMISSIONS,
    '__module__' : 'permissionmessages_pb2'
    # @@protoc_insertion_point(class_scope:permission_messages.PermissionsType.CachePermissions)
    })
  ,

  'TopicSelector' : _reflection.GeneratedProtocolMessageType('TopicSelector', (_message.Message,), {
    'DESCRIPTOR' : _PERMISSIONSTYPE_TOPICSELECTOR,
    '__module__' : 'permissionmessages_pb2'
    # @@protoc_insertion_point(class_scope:permission_messages.PermissionsType.TopicSelector)
    })
  ,

  'TopicPermissions' : _reflection.GeneratedProtocolMessageType('TopicPermissions', (_message.Message,), {
    'DESCRIPTOR' : _PERMISSIONSTYPE_TOPICPERMISSIONS,
    '__module__' : 'permissionmessages_pb2'
    # @@protoc_insertion_point(class_scope:permission_messages.PermissionsType.TopicPermissions)
    })
  ,
  'DESCRIPTOR' : _PERMISSIONSTYPE,
  '__module__' : 'permissionmessages_pb2'
  # @@protoc_insertion_point(class_scope:permission_messages.PermissionsType)
  })
_sym_db.RegisterMessage(PermissionsType)
_sym_db.RegisterMessage(PermissionsType.All)
_sym_db.RegisterMessage(PermissionsType.CacheSelector)
_sym_db.RegisterMessage(PermissionsType.CacheItemSelector)
_sym_db.RegisterMessage(PermissionsType.CachePermissions)
_sym_db.RegisterMessage(PermissionsType.TopicSelector)
_sym_db.RegisterMessage(PermissionsType.TopicPermissions)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030grpc.permission_messagesP\001Z0github.com/momentohq/client-sdk-go;client_sdk_go\252\002!Momento.Protos.PermissionMessages'
  _CACHEROLE._serialized_start=1419
  _CACHEROLE._serialized_end=1510
  _TOPICROLE._serialized_start=1512
  _TOPICROLE._serialized_end=1603
  _SUPERUSERPERMISSIONS._serialized_start=1605
  _SUPERUSERPERMISSIONS._serialized_end=1642
  _PERMISSIONS._serialized_start=50
  _PERMISSIONS._serialized_end=198
  _EXPLICITPERMISSIONS._serialized_start=200
  _EXPLICITPERMISSIONS._serialized_end=280
  _PERMISSIONSTYPE._serialized_start=283
  _PERMISSIONSTYPE._serialized_end=1417
  _PERMISSIONSTYPE_ALL._serialized_start=470
  _PERMISSIONSTYPE_ALL._serialized_end=475
  _PERMISSIONSTYPE_CACHESELECTOR._serialized_start=477
  _PERMISSIONSTYPE_CACHESELECTOR._serialized_end=522
  _PERMISSIONSTYPE_CACHEITEMSELECTOR._serialized_start=524
  _PERMISSIONSTYPE_CACHEITEMSELECTOR._serialized_end=588
  _PERMISSIONSTYPE_CACHEPERMISSIONS._serialized_start=591
  _PERMISSIONSTYPE_CACHEPERMISSIONS._serialized_end=964
  _PERMISSIONSTYPE_TOPICSELECTOR._serialized_start=966
  _PERMISSIONSTYPE_TOPICSELECTOR._serialized_end=1040
  _PERMISSIONSTYPE_TOPICPERMISSIONS._serialized_start=1043
  _PERMISSIONSTYPE_TOPICPERMISSIONS._serialized_end=1409
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

CachePermitNone: CacheRole
CacheReadOnly: CacheRole
CacheReadWrite: CacheRole
CacheWriteOnly: CacheRole
DESCRIPTOR: _descriptor.FileDescriptor
SuperUser: SuperUserPermissions
TopicPermitNone: TopicRole
TopicReadOnly: TopicRole
TopicReadWrite: TopicRole
TopicWriteOnly: TopicRole

class ExplicitPermissions(_message.Message):
    __slots__ = ["permissions"]
    PERMISSIONS_FIELD_NUMBER: _ClassVar[int]
    permissions: _containers.RepeatedCompositeFieldContainer[PermissionsType]
    def __init__(self, permissions: _Optional[_Iterable[_Union[PermissionsType, _Mapping]]] = ...) -> None: ...

class Permissions(_message.Message):
    __slots__ = ["explicit", "super_user"]
    EXPLICIT_FIELD_NUMBER: _ClassVar[int]
    SUPER_USER_FIELD_NUMBER: _ClassVar[int]
    explicit: ExplicitPermissions
    super_user: SuperUserPermissions
    def __init__(self, super_user: _Optional[_Union[SuperUserPermissions, str]] = ..., explicit: _Optional[_Union[ExplicitPermissions, _Mapping]] = ...) -> None: ...

class PermissionsType(_message.Message):
    __slots__ = ["cache_permissions", "topic_permissions"]
    class All(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    class CacheItemSelector(_message.Message):
        __slots__ = ["key", "key_prefix"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        KEY_PREFIX_FIELD_NUMBER: _ClassVar[int]
        key: bytes
        key_prefix: bytes
        def __init__(self, key: _Optional[bytes] = ..., key_prefix: _Optional[bytes] = ...) -> None: ...
    class CachePermissions(_message.Message):
        __slots__ = ["all_caches", "all_items", "cache_selector", "item_selector", "role"]
        ALL_CACHES_FIELD_NUMBER: _ClassVar[int]
        ALL_ITEMS_FIELD_NUMBER: _ClassVar[int]
        CACHE_SELECTOR_FIELD_NUMBER: _ClassVar[int]
        ITEM_SELECTOR_FIELD_NUMBER: _ClassVar[int]
        ROLE_FIELD_NUMBER: _ClassVar[int]
        all_caches: PermissionsType.All
        all_items: PermissionsType.All
        cache_selector: PermissionsType.CacheSelector
        item_selector: PermissionsType.CacheItemSelector
        role: CacheRole
        def __init__(self, role: _Optional[_Union[CacheRole, str]] = ..., all_caches: _Optional[_Union[PermissionsType.All, _Mapping]] = ..., cache_selector: _Optional[_Union[PermissionsType.CacheSelector, _Mapping]] = ..., all_items: _Optional[_Union[PermissionsType.All, _Mapping]] = ..., item_selector: _Optional[_Union[PermissionsType.CacheItemSelector, _Mapping]] = ...) -> None: ...
    class CacheSelector(_message.Message):
        __slots__ = ["cache_name"]
        CACHE_NAME_FIELD_NUMBER: _ClassVar[int]
        cache_name: str
        def __init__(self, cache_name: _Optional[str] = ...) -> None: ...
    class TopicPermissions(_message.Message):
        __slots__ = ["all_caches", "all_topics", "cache_selector", "role", "topic_selector"]
        ALL_CACHES_FIELD_NUMBER: _ClassVar[int]
        ALL_TOPICS_FIELD_NUMBER: _ClassVar[int]
        CACHE_SELECTOR_FIELD_NUMBER: _ClassVar[int]
        ROLE_FIELD_NUMBER: _ClassVar[int]
        TOPIC_SELECTOR_FIELD_NUMBER: _ClassVar[int]
        all_caches: PermissionsType.All
        all_topics: PermissionsType.All
        cache_selector: PermissionsType.CacheSelector
        role: TopicRole
        topic_selector: PermissionsType.TopicSelector
        def __init__(self, role: _Optional[_Union[TopicRole, str]] = ..., all_caches: _Optional[_Union[PermissionsType.All, _Mapping]] = ..., cache_selector: _Optional[_Union[PermissionsType.CacheSelector, _Mapping]] = ..., all_topics: _Optional[_Union[PermissionsType.All, _Mapping]] = ..., topic_selector: _Optional[_Union[PermissionsType.TopicSelector, _Mapping]] = ...) -> None: ...
    class TopicSelector(_message.Message):
        __slots__ = ["topic_name", "topic_name_prefix"]
        TOPIC_NAME_FIELD_NUMBER: _ClassVar[int]
        TOPIC_NAME_PREFIX_FIELD_NUMBER: _ClassVar[int]
        topic_name: str
        topic_name_prefix: str
        def __init__(self, topic_name: _Optional[str] = ..., topic_name_prefix: _Optional[str] = ...) -> None: ...
    CACHE_PERMISSIONS_FIELD_NUMBER: _ClassVar[int]
    TOPIC_PERMISSIONS_FIELD_NUMBER: _ClassVar[int]
    cache_permissions: PermissionsType.CachePermissions
    topic_permissions: PermissionsType.TopicPermissions
    def __init__(self, cache_permissions: _Optional[_Union[PermissionsType.CachePermissions, _Mapping]] = ..., topic_permissions: _Optional[_Union[PermissionsType.TopicPermissions, _Mapping]] = ...) -> None: ...

class CacheRole(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class TopicRole(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class SuperUserPermissions(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: extensions.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x65xtensions.proto\x1a google/protobuf/descriptor.proto*0\n\rRetrySemantic\x12\x10\n\x0cNotRetryable\x10\x00\x12\r\n\tRetryable\x10\x01:I\n\x0eretry_semantic\x12\x1f.google.protobuf.MessageOptions\x18\xd0\x86\x03 \x01(\x0e\x32\x0e.RetrySemanticB_\n\x0fgrpc.extensionsZ0github.com/momentohq/client-sdk-go;client_sdk_go\xaa\x02\x19Momento.Protos.Extensionsb\x06proto3')

_RETRYSEMANTIC = DESCRIPTOR.enum_types_by_name['RetrySemantic']
RetrySemantic = enum_type_wrapper.EnumTypeWrapper(_RETRYSEMANTIC)
NotRetryable = 0
Retryable = 1

RETRY_SEMANTIC_FIELD_NUMBER = 50000
retry_semantic = DESCRIPTOR.extensions_by_name['retry_semantic']

if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(retry_semantic)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017grpc.extensionsZ0github.com/momentohq/client-sdk-go;client_sdk_go\252\002\031Momento.Protos.Extensions'
  _RETRYSEMANTIC._serialized_start=54
  _RETRYSEMANTIC._serialized_end=102
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
NotRetryable: RetrySemantic
RETRY_SEMANTIC_FIELD_NUMBER: _ClassVar[int]
Retryable: RetrySemantic
retry_semantic: _descriptor.FieldDescriptor

class RetrySemantic(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class _Cache(_message.Message):
    __slots__ = ["cache_limits", "cache_name", "topic_limits"]
    CACHE_LIMITS_FIELD_NUMBER: _ClassVar[int]
    CACHE_NAME_FIELD_NUMBER: _ClassVar[int]
    TOPIC_LIMITS_FIELD_NUMBER: _ClassVar[int]
    cache_limits: _CacheLimits
    cache_name: str
    topic_limits: _TopicLimits
    def __init__(self, cache_name: _Optional[str] = ..., cache_limits: _Optional[_Union[_CacheLimits, _Mapping]] = ..., topic_limits: _Optional[_Union[_TopicLimits, _Mapping]] = ...) -> None: ...

class _CacheLimits(_message.Message):
    __slots__ = ["max_item_size_kb", "max_throughput_kbps", "max_traffic_rate", "max_ttl_seconds"]
    MAX_ITEM_SIZE_KB_FIELD_NUMBER: _ClassVar[int]
    MAX_THROUGHPUT_KBPS_FIELD_NUMBER: _ClassVar[int]
    MAX_TRAFFIC_RATE_FIELD_NUMBER: _ClassVar[int]
    MAX_TTL_SECONDS_FIELD_NUMBER: _ClassVar[int]
    max_item_size_kb: int
    max_throughput_kbps: int
    max_traffic_rate: int
    max_ttl_seconds: int
    def __init__(self, max_traffic_rate: _Optional[int] = ..., max_throughput_kbps: _Optional[int] = ..., max_item_size_kb: _Optional[int] = ..., max_ttl_seconds: _Optional[int] = ...) -> None: ...

class _CreateCacheRequest(_message.Message):
    __slots__ = ["cache_name"]
    CACHE_NAME_FIELD_NUMBER: _ClassVar[int]
    cache_name: str
    def __init__(self, cache_name: _Optional[str] = ...) -> None: ...

class _CreateCacheResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class _CreateIndexRequest(_message.Message):
    __slots__ = ["index_name", "num_dimensions", "similarity_metric"]
    INDEX_NAME_FIELD_NUMBER: _ClassVar[int]
    NUM_DIMENSIONS_FIELD_NUMBER: _ClassVar[int]
    SIMILARITY_METRIC_FIELD_NUMBER: _ClassVar[int]
    index_name: str
    num_dimensions: int
    similarity_metric: _SimilarityMetric
    def __init__(self, index_name: _Optional[str] = ..., num_dimensions: _Optional[int] = ..., similarity_metric: _Optional[_Union[_SimilarityMetric, _Mapping]] = ...) -> None: ...

class _CreateIndexResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class _CreateSigningKeyRequest(_message.Message):
    __slots__ = ["ttl_minutes"]
    TTL_MINUTES_FIELD_NUMBER: _ClassVar[int]
    ttl_minutes: int
    def __init__(self, ttl_minutes: _Optional[int] = ...) -> None: ...

class _CreateSigningKeyResponse(_message.Message):
    __slots__ = ["expires_at", "key"]
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    expires_at: int
    key: str
    def __init__(self, key: _Optional[str] = ..., expires_at: _Optional[int] = ...) -> None: ...

class _CreateStoreRequest(_message.Message):
    __slots__ = ["store_name"]
    STORE_NAME_FIELD_NUMBER: _ClassVar[int]
    store_name: str
    def __init__(self, store_name: _Optional[str] = ...) -> None: ...

class _CreateStoreResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class _DeleteCacheRequest(_message.Message):
    __slots__ = ["cache_name"]
    CACHE_NAME_FIELD_NUMBER: _ClassVar[int]
    cache_name: str
    def __init__(self, cache_name: _Optional[str] = ...) -> None: ...

class _DeleteCacheResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class _DeleteIndexRequest(_message.Message):
    __slots__ = ["index_name"]
    INDEX_NAME_FIELD_NUMBER: _ClassVar[int]
    index_name: str
    def __init__(self, index_name: _Optional[str] = ...) -> None: ...

class _DeleteIndexResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class _DeleteStoreRequest(_message.Message):
    __slots__ = ["store_name"]
    STORE_NAME_FIELD_NUMBER: _ClassVar[int]
    store_name: str
    def __init__(self, store_name: _Optional[str] = ...) -> None: ...

class _DeleteStoreResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class _FlushCacheRequest(_message.Message):
    __slots__ = ["cache_name"]
    CACHE_NAME_FIELD_NUMBER: _ClassVar[int]
    cache_name: str
    def __init__(self, cache_name: _Optional[str] = ...) -> None: ...

class _FlushCacheResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class _ListCachesRequest(_message.Message):
    __slots__ = ["next_token"]
    NEXT_TOKEN_FIELD_NUMBER: _ClassVar[int]
    next_token: str
    def __init__(self, next_token: _Optional[str] = ...) -> None: ...

class _ListCachesResponse(_message.Message):
    __slots__ = ["cache", "next_token"]
    CACHE_FIELD_NUMBER: _ClassVar[int]
    NEXT_TOKEN_FIELD_NUMBER: _ClassVar[int]
    cache: _containers.RepeatedCompositeFieldContainer[_Cache]
    next_token: str
    def __init__(self, cache: _Optional[_Iterable[_Union[_Cache, _Mapping]]] = ..., next_token: _Optional[str] = ...) -> None: ...

class _ListIndexesRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class _ListIndexesResponse(_message.Message):
    __slots__ = ["indexes"]
    class _Index(_message.Message):
        __slots__ = ["index_name", "num_dimensions", "similarity_metric"]
        INDEX_NAME_FIELD_NUMBER: _ClassVar[int]
        NUM_DIMENSIONS_FIELD_NUMBER: _ClassVar[int]
        SIMILARITY_METRIC_FIELD_NUMBER: _ClassVar[int]
        index_name: str
        num_dimensions: int
        similarity_metric: _SimilarityMetric
        def __init__(self, index_name: _Optional[str] = ..., num_dimensions: _Optional[int] = ..., similarity_metric: _Optional[_Union[_SimilarityMetric, _Mapping]] = ...) -> None: ...
    INDEXES_FIELD_NUMBER: _ClassVar[int]
    indexes: _containers.RepeatedCompositeFieldContainer[_ListIndexesResponse._Index]
    def __init__(self, indexes: _Optional[_Iterable[_Union[_ListIndexesResponse._Index, _Mapping]]] = ...) -> None: ...

class _ListSigningKeysRequest(_message.Message):
    __slots__ = ["next_token"]
    NEXT_TOKEN_FIELD_NUMBER: _ClassVar[int]
    next_token: str
    def __init__(self, next_token: _Optional[str] = ...) -> None: ...

class _ListSigningKeysResponse(_message.Message):
    __slots__ = ["next_token", "signing_key"]
    NEXT_TOKEN_FIELD_NUMBER: _ClassVar[int]
    SIGNING_KEY_FIELD_NUMBER: _ClassVar[int]
    next_token: str
    signing_key: _containers.RepeatedCompositeFieldContainer[_SigningKey]
    def __init__(self, signing_key: _Optional[_Iterable[_Union[_SigningKey, _Mapping]]] = ..., next_token: _Optional[str] = ...) -> None: ...

class _ListStoresRequest(_message.Message):
    __slots__ = ["next_token"]
    NEXT_TOKEN_FIELD_NUMBER: _ClassVar[int]
    next_token: str
    def __init__(self, next_token: _Optional[str] = ...) -> None: ...

class _ListStoresResponse(_message.Message):
    __slots__ = ["next_token", "store"]
    NEXT_TOKEN_FIELD_NUMBER: _ClassVar[int]
    STORE_FIELD_NUMBER: _ClassVar[int]
    next_token: str
    store: _containers.RepeatedCompositeFieldContainer[_Store]
    def __init__(self, store: _Optional[_Iterable[_Union[_Store, _Mapping]]] = ..., next_token: _Optional[str] = ...) -> None: ...

class _RevokeSigningKeyRequest(_message.Message):
    __slots__ = ["key_id"]
    KEY_ID_FIELD_NUMBER: _ClassVar[int]
    key_id: str
    def __init__(self, key_id: _Optional[str] = ...) -> None: ...

class _RevokeSigningKeyResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class _SigningKey(_message.Message):
    __slots__ = ["expires_at", "key_id"]
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    KEY_ID_FIELD_NUMBER: _ClassVar[int]
    expires_at: int
    key_id: str
    def __init__(self, key_id: _Optional[str] = ..., expires_at: _Optional[int] = ...) -> None: ...

class _SimilarityMetric(_message.Message):
    __slots__ = ["cosine_similarity", "euclidean_similarity", "inner_product"]
    class _CosineSimilarity(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    class _EuclideanSimilarity(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    class _InnerProduct(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    COSINE_SIMILARITY_FIELD_NUMBER: _ClassVar[int]
    EUCLIDEAN_SIMILARITY_FIELD_NUMBER: _ClassVar[int]
    INNER_PRODUCT_FIELD_NUMBER: _ClassVar[int]
    cosine_similarity: _SimilarityMetric._CosineSimilarity
    euclidean_similarity: _SimilarityMetric._EuclideanSimilarity
    inner_product: _SimilarityMetric._InnerProduct
    def __init__(self, euclidean_similarity: _Optional[_Union[_SimilarityMetric._EuclideanSimilarity, _Mapping]] = ..., inner_product: _Optional[_Union[_SimilarityMetric._InnerProduct, _Mapping]] = ..., cosine_similarity: _Optional[_Union[_SimilarityMetric._CosineSimilarity, _Mapping]] = ...) -> None: ...

class _Store(_message.Message):
    __slots__ = ["store_name"]
    STORE_NAME_FIELD_NUMBER: _ClassVar[int]
    store_name: str
    def __init__(self, store_name: _Optional[str] = ...) -> None: ...

class _TopicLimits(_message.Message):
    __slots__ = ["max_publish_message_size_kb", "max_publish_rate", "max_subscription_count"]
    MAX_PUBLISH_MESSAGE_SIZE_KB_FIELD_NUMBER: _ClassVar[int]
    MAX_PUBLISH_RATE_FIELD_NUMBER: _ClassVar[int]
    MAX_SUBSCRIPTION_COUNT_FIELD_NUMBER: _ClassVar[int]
    max_publish_message_size_kb: int
    max_publish_rate: int
    max_subscription_count: int
    def __init__(self, max_publish_rate: _Optional[int] = ..., max_subscription_count: _Optional[int] = ..., max_publish_message_size_kb: _Optional[int] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import cachepubsub_pb2 as cachepubsub__pb2
import common_pb2 as common__pb2


class PubsubStub(object):
    """For working with topics in a cache.
    Momento topics are conceptually located on a cache. They are best-effort multicast.
    To use them, create a cache then start subscribing and publishing!

    Momento topic subscriptions try to give you information about the quality of the
    stream you are receiving. For example, you might miss messages if your network
    is slow, or if some intermediate switch fails, or due to rate limiting. It is
    also possible, though we try to avoid it, that messages could briefly come out
    of order between subscribers.
    We try to tell you when things like this happen via a Discontinuity in your
    subscription stream. If you do not care about occasional discontinuities then
    don't bother handling them! You might still want to log them just in case ;-)
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Publish = channel.unary_unary(
                '/cache_client.pubsub.Pubsub/Publish',
                request_serializer=cachepubsub__pb2._PublishRequest.SerializeToString,
                response_deserializer=common__pb2._Empty.FromString,
                )
        self.Subscribe = channel.unary_stream(
                '/cache_client.pubsub.Pubsub/Subscribe',
                request_serializer=cachepubsub__pb2._SubscriptionRequest.SerializeToString,
                response_deserializer=cachepubsub__pb2._SubscriptionItem.FromString,
                )


class PubsubServicer(object):
    """For working with topics in a cache.
    Momento topics are conceptually located on a cache. They are best-effort multicast.
    To use them, create a cache then start subscribing and publishing!

    Momento topic subscriptions try to give you information about the quality of the
    stream you are receiving. For example, you might miss messages if your network
    is slow, or if some intermediate switch fails, or due to rate limiting. It is
    also possible, though we try to avoid it, that messages could briefly come out
    of order between subscribers.
    We try to tell you when things like this happen via a Discontinuity in your
    subscription stream. If you do not care about occasional discontinuities then
    don't bother handling them! You might still want to log them just in case ;-)
    """

    def Publish(self, request, context):
        """Publish a message to a topic.

        If a topic has no subscribers, then the effect of Publish MAY be either of:
        * It is dropped and the topic is nonexistent.
        * It is accepted to the topic as the next message.

        Publish() does not wait for subscribers to accept. It returns Ok upon accepting
        the topic value. It also returns Ok if there are no subscribers and the value
        happens to be dropped. Publish() can not guarantee delivery in theory but in
        practice it should almost always deliver to subscribers.

        REQUIRES HEADER authorization: Momento auth token
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Subscribe(self, request, context):
        """Subscribe to notifications from a topic.

        You will receive a stream of values and (hopefully occasional) discontinuities.
        Values will appear as copies of the payloads you Publish() to the topic.

        REQUIRES HEADER authorization: Momento auth token
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PubsubServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Publish': grpc.unary_unary_rpc_method_handler(
                    servicer.Publish,
                    request_deserializer=cachepubsub__pb2._PublishRequest.FromString,
                    response_serializer=common__pb2._Empty.SerializeToString,
            ),
            'Subscribe': grpc.unary_stream_rpc_method_handler(
                    servicer.Subscribe,
                    request_deserializer=cachepubsub__pb2._SubscriptionRequest.FromString,
                    response_serializer=cachepubsub__pb2._SubscriptionItem.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cache_client.pubsub.Pubsub', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Pubsub(object):
    """For working with topics in a cache.
    Momento topics are conceptually located on a cache. They are best-effort multicast.
    To use them, create a cache then start subscribing and publishing!

    Momento topic subscriptions try to give you information about the quality of the
    stream you are receiving. For example, you might miss messages if your network
    is slow, or if some intermediate switch fails, or due to rate limiting. It is
    also possible, though we try to avoid it, that messages could briefly come out
    of order between subscribers.
    We try to tell you when things like this happen via a Discontinuity in your
    subscription stream. If you do not care about occasional discontinuities then
    don't bother handling them! You might still want to log them just in case ;-)
    """

    @staticmethod
    def Publish(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cache_client.pubsub.Pubsub/Publish',
            cachepubsub__pb2._PublishRequest.SerializeToString,
            common__pb2._Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Subscribe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/cache_client.pubsub.Pubsub/Subscribe',
            cachepubsub__pb2._SubscriptionRequest.SerializeToString,
            cachepubsub__pb2._SubscriptionItem.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import permissionmessages_pb2 as _permissionmessages_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class _GenerateDisposableTokenRequest(_message.Message):
    __slots__ = ["auth_token", "expires", "permissions", "token_id"]
    class Expires(_message.Message):
        __slots__ = ["valid_for_seconds"]
        VALID_FOR_SECONDS_FIELD_NUMBER: _ClassVar[int]
        valid_for_seconds: int
        def __init__(self, valid_for_seconds: _Optional[int] = ...) -> None: ...
    AUTH_TOKEN_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_FIELD_NUMBER: _ClassVar[int]
    PERMISSIONS_FIELD_NUMBER: _ClassVar[int]
    TOKEN_ID_FIELD_NUMBER: _ClassVar[int]
    auth_token: str
    expires: _GenerateDisposableTokenRequest.Expires
    permissions: _permissionmessages_pb2.Permissions
    token_id: str
    def __init__(self, expires: _Optional[_Union[_GenerateDisposableTokenRequest.Expires, _Mapping]] = ..., auth_token: _Optional[str] = ..., permissions: _Optional[_Union[_permissionmessages_pb2.Permissions, _Mapping]] = ..., token_id: _Optional[str] = ...) -> None: ...

class _GenerateDisposableTokenResponse(_message.Message):
    __slots__ = ["api_key", "endpoint", "valid_until"]
    API_KEY_FIELD_NUMBER: _ClassVar[int]
    ENDPOINT_FIELD_NUMBER: _ClassVar[int]
    VALID_UNTIL_FIELD_NUMBER: _ClassVar[int]
    api_key: str
    endpoint: str
    valid_until: int
    def __init__(self, api_key: _Optional[str] = ..., endpoint: _Optional[str] = ..., valid_until: _Optional[int] = ...) -> None: ...



import google.protobuf as protobuf

try:
    protobuf_version = protobuf.__version__.split(".")
    major = int(protobuf_version[0])
    minor = int(protobuf_version[1])
except ValueError:
    raise ValueError("Could not parse protobuf version: {}".format(protobuf.__version__))

# Import the correct version of the generated code.
# To accomodate the dynamic imports, we must now write code like:
#       from momento_wire_types import cacheclient_pb2 as cache_pb
#       request = cache_pb.GetRequest()
# instead of:
#       from momento_wire_types.cacheclient_pb2 import GetRequest
#       request = GetRequest()
# This because the multi-level from will not work with the dynamic imports.
if major >= 4 or (major == 3 and minor >= 20):
    from .v4 import auth_pb2 as auth_pb2
    from .v4 import auth_pb2_grpc as auth_pb2_grpc
    from .v4 import cacheclient_pb2 as cacheclient_pb2
    from .v4 import cacheclient_pb2_grpc as cacheclient_pb2_grpc
    from .v4 import cachepubsub_pb2 as cachepubsub_pb2
    from .v4 import cachepubsub_pb2_grpc as cachepubsub_pb2_grpc
    from .v4 import controlclient_pb2 as controlclient_pb2
    from .v4 import controlclient_pb2_grpc as controlclient_pb2_grpc
    from .v4 import extensions_pb2 as extensions_pb2
    from .v4 import extensions_pb2_grpc as extensions_pb2_grpc
    from .v4 import permissionmessages_pb2 as permissionmessages_pb2
    from .v4 import permissionmessages_pb2_grpc as permissionmessages_pb2_grpc
    from .v4 import token_pb2 as token_pb2
    from .v4 import token_pb2_grpc as token_pb2_grpc
    from .v4 import vectorindex_pb2 as vectorindex_pb2
    from .v4 import vectorindex_pb2_grpc as vectorindex_pb2_grpc

else:
    from .v319 import auth_pb2 as auth_pb2
    from .v319 import auth_pb2_grpc as auth_pb2_grpc
    from .v319 import cacheclient_pb2 as cacheclient_pb2
    from .v319 import cacheclient_pb2_grpc as cacheclient_pb2_grpc
    from .v319 import cachepubsub_pb2 as cachepubsub_pb2
    from .v319 import cachepubsub_pb2_grpc as cachepubsub_pb2_grpc
    from .v319 import controlclient_pb2 as controlclient_pb2
    from .v319 import controlclient_pb2_grpc as controlclient_pb2_grpc
    from .v319 import extensions_pb2 as extensions_pb2
    from .v319 import extensions_pb2_grpc as extensions_pb2_grpc
    from .v319 import permissionmessages_pb2 as permissionmessages_pb2
    from .v319 import permissionmessages_pb2_grpc as permissionmessages_pb2_grpc
    from .v319 import token_pb2 as token_pb2
    from .v319 import token_pb2_grpc as token_pb2_grpc
    from .v319 import vectorindex_pb2 as vectorindex_pb2
    from .v319 import vectorindex_pb2_grpc as vectorindex_pb2_grpc


__all__ = ["auth_pb2", "auth_pb2_grpc", "cacheclient_pb2", "cacheclient_pb2_grpc", "cachepubsub_pb2", "cachepubsub_pb2_grpc", "controlclient_pb2", "controlclient_pb2_grpc", "extensions_pb2", "extensions_pb2_grpc", "permissionmessages_pb2", "permissionmessages_pb2_grpc", "token_pb2", "token_pb2_grpc", "vectorindex_pb2", "vectorindex_pb2_grpc"]